pub fn constraint_type(type_id: &str) -> Option<&'static ConstraintTypeDef>Expand description
Look up a type definition by its canonical type string.
pub fn constraint_type(type_id: &str) -> Option<&'static ConstraintTypeDef>Look up a type definition by its canonical type string.