export_iges

Function export_iges 

pub fn export_iges(
    solids: &[BrepSolid],
    name: &str,
    unit: &str,
    timestamp: &str,
) -> Result<String, String>
Serialize solids as an IGES 5.3 document of trimmed NURBS surfaces.

unit is one of millimeter|meter|centimeter|inch|foot (default millimetre); coordinates are written verbatim, so callers should pass the unit the kernel geometry is expressed in (millimetres in this kernel).