split_solid_by_surface_json

Function split_solid_by_surface_json 

pub fn split_solid_by_surface_json(
    request_json: &str,
) -> Result<String, JsValue>
Cut a solid by an analytic tool surface (Golovanov 6.4). The request is { "solid": <solid>, "tool": { "type": "cylinder"|"sphere"|"cone"|"torus"| "plane", ... } }. Returns { "pieces": [<inside>, <outside>] } (for a plane, [below, above]). Errors with “tool surface does not divide the solid” when the tool does not cleanly cut the body.