pub fn set_once()Expand description
Install the panic hook, at most once per module instance. Cheap enough to call from every entry point, which is how it is used.
pub fn set_once()Install the panic hook, at most once per module instance. Cheap enough to call from every entry point, which is how it is used.