pub struct CoedgeId(/* private fields */);Trait Implementations
impl Copy for CoedgeId
impl Eq for CoedgeId
Sourceimpl Key for CoedgeId
impl Key for CoedgeId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for CoedgeId
impl Ord for CoedgeId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for CoedgeId
impl PartialOrd for CoedgeId
impl StructuralPartialEq for CoedgeId