pub struct LoopId(/* private fields */);Trait Implementations
impl Copy for LoopId
impl Eq for LoopId
Sourceimpl Key for LoopId
impl Key for LoopId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for LoopId
impl Ord for LoopId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for LoopId
impl PartialOrd for LoopId
impl StructuralPartialEq for LoopId