pub struct MeshRegion {
pub id: u32,
pub triangle_count: usize,
pub area: f64,
pub bbox_min: Vec3,
pub bbox_max: Vec3,
pub carrier: RegionCarrier,
pub max_deviation: f64,
pub rms_deviation: f64,
pub max_normal_angle_deg: f64,
}Expand description
One smooth region of the mesh with its recognized carrier and fit
residuals (residuals are zero for Freeform regions — no fit).
Fields
id: u32triangle_count: usizearea: f64bbox_min: Vec3bbox_max: Vec3carrier: RegionCarriermax_deviation: f64Maximum absolute vertex deviation from the accepted carrier.
rms_deviation: f64Root-mean-square vertex deviation from the accepted carrier.
max_normal_angle_deg: f64Maximum angle between a triangle normal and the carrier normal, deg.