pub struct RevolutionStructure {
pub frame: RevolutionFrame,
pub generatrix: NurbsCurve,
pub sweep: f64,
}Expand description
Frame, generatrix, and sweep of any surface built by make_revolution
(full or partial), validated by exact reconstruction. Unlike
AnalyticSurface this does not require the generatrix to be a line or
classic quadric profile.
Fields
frame: RevolutionFramegeneratrix: NurbsCurvesweep: f64Auto Trait Implementations
impl !Freeze for RevolutionStructure
impl !RefUnwindSafe for RevolutionStructure
impl !Sync for RevolutionStructure
impl Send for RevolutionStructure
impl Unpin for RevolutionStructure
impl UnsafeUnpin for RevolutionStructure
impl UnwindSafe for RevolutionStructure