pub struct ShellId(/* private fields */);Trait Implementations
impl Copy for ShellId
impl Eq for ShellId
Sourceimpl Key for ShellId
impl Key for ShellId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ShellId
impl Ord for ShellId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ShellId
impl PartialOrd for ShellId
impl StructuralPartialEq for ShellId