pub struct VertexId(/* private fields */);Trait Implementations
impl Copy for VertexId
impl Eq for VertexId
Sourceimpl Key for VertexId
impl Key for VertexId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for VertexId
impl Ord for VertexId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for VertexId
impl PartialOrd for VertexId
impl StructuralPartialEq for VertexId