pub type PartsLibraryMap = BTreeMap<String, PartsLibraryEntry>;Expand description
The library map shape as it travels in the history request / save file.
Aliased Type
pub struct PartsLibraryMap { /* private fields */ }pub type PartsLibraryMap = BTreeMap<String, PartsLibraryEntry>;The library map shape as it travels in the history request / save file.
pub struct PartsLibraryMap { /* private fields */ }